#include "testApp.h"


//--------------------------------------------------------------
void testApp::setup(){

    ifstream fin; //declare a file stream

    mShowReadme = false; // will only be enabled if a readme.txt file is found (and not empty)
    mFullscreen = false;
    mMouseDown = false;

    ofSetFrameRate ( 30 );
    ofSetVerticalSync ( true );
    ofBackground ( 0,0,0 );

    mTextureImage.loadImage("circle.png");

    // load readme.txt into readme line vector:
    fin.open( ofToDataPath("readme.txt").c_str() );
    while(fin!=NULL) //as long as theres still text to be read
    {
        string str; //declare a string for storage
        getline(fin, str); //get a line from the file, put it in the string
        mReadme.push_back(str); //push the string onto a vector of strings
    }
    if ( mReadme.size() > 0 ) mShowReadme = true;

    mParticleController = new ParticleController ( mTextureImage.getTextureReference(), ofxVec2f ( ofGetWidth() / 2, ofGetHeight() - 10 ), 3, 10.0, 20.0, -90.0, 20.0 );
}

//--------------------------------------------------------------
void testApp::update(){

    if ( mMouseDown )
    {
        mParticleController->mPosition = mMousePos;
    }
    mParticleController->update ();

}

//--------------------------------------------------------------
void testApp::draw(){

    mParticleController->draw ();

    ofSetColor ( 0xFF0080 );
    ofDrawBitmapString ( "FPS: " + ofToString ( ofGetFrameRate() ), 10, 20 );
    ofDrawBitmapString ( "Particles: " + ofToString ( mParticleController->getParticleCount() ), 10, 30 );
    //ofSetColor ( 0x0080FF );
    //ofDrawBitmapString ( "Press/drag mouse to spawn particles", ofGetWidth() - (35*8) - 10, 20 );

    if ( mShowReadme ) {
        float heightLine = 12;
        float padding = 10;
        float heightInternal = (mReadme.size() + 2) * heightLine;
        float widthInternal = 81 * 8;

        ofPushMatrix ();
        ofEnableAlphaBlending ();
        ofTranslate ( ( ofGetWidth() - widthInternal ) / 2, ( ofGetHeight() - heightInternal ) / 2, 0 );

        ofSetColor ( 0, 0, 0, 230 );
        ofFill ();
        ofRect ( -padding, -padding, widthInternal + padding, heightInternal + padding );

        ofSetColor ( 255, 255, 255, 255 );
        ofNoFill ();
        ofRect ( -padding, -padding, widthInternal + padding, heightInternal + padding );

        for( int i = 0; i < mReadme.size(); i++ ) {
            ofDrawBitmapString ( mReadme[i], 0, heightLine + i * heightLine );
        }

        ofSetColor ( 170, 170, 170, 255 );
        ofDrawBitmapString ( "Press any key to hide this message", 0, heightLine + mReadme.size() * heightLine );

        ofDisableAlphaBlending ();
        ofPopMatrix ();
    }
}

//--------------------------------------------------------------
void testApp::keyPressed  (int key){
    switch (key){
        case 'f':
        case 'F':
            mFullscreen = !mFullscreen;
            ofSetFullscreen ( mFullscreen );
            break;
        default:
            if ( mShowReadme ) mShowReadme = false;
            break;
    }
}

//--------------------------------------------------------------
void testApp::keyReleased  (int key){
}

//--------------------------------------------------------------
void testApp::mouseMoved(int x, int y ){
    mMousePos = ofxVec2f ( x, y );
}

//--------------------------------------------------------------
void testApp::mouseDragged(int x, int y, int button){
    mMousePos = ofxVec2f ( x, y );
}

//--------------------------------------------------------------
void testApp::mousePressed(int x, int y, int button){
    mMouseDown = true;
    mMousePos = ofxVec2f ( x, y );
}

//--------------------------------------------------------------
void testApp::mouseReleased(int x, int y, int button){
    mMouseDown = false;
}

void testApp::windowResized(int w, int h){
}
